function [X_new, Y_new]=data_interp(X, Y)
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
%
% This program is designed to match the time ranges of two matrices and
% interpolate the smaller matrix to match the length of the larger matrix.
% 
% Inputs are two matrices of varying length and time frame.
% Outputs are two matrices with the same length and time frame.
%
% The output matrices will be returned corresponding to the same order
% that the input matrices were submitted
% example: [X_interpolate, Y_interpolated] = data_interp(X,Y)
%
% NOTE: Both matrices MUST have their first column be a unix time vector
% 
% % Remove all NaN's from both matrices
% X = X(~isnan(X(:,2)),:);
% Y = Y(~isnan(Y(:,2)),:);

% Find the data points of each matrix with overlapping time frames
overlap_X = X((X(:,1)>=Y(1,1) & X(:,1)<=Y(end,1)),:);
overlap_Y = Y((Y(:,1)>=X(1,1) & Y(:,1)<=X(end,1)),:);

X_len = length(overlap_X);
Y_len = length(overlap_Y);

% Check which matrix is larger or smaller
if (X_len>Y_len)
    long_matrix = overlap_X;
    short_matrix = overlap_Y;
elseif(Y_len>X_len)
    long_matrix = overlap_Y;
    short_matrix = overlap_X;
else
    X_new = overlap_X;
    Y_new = overlap_Y;
    return
end

interped_matrix = interp1(short_matrix(:,1), short_matrix, long_matrix(:,1)); %interpolate smaller matrix according to unix time vector
interped_matrix(:,1) = long_matrix(:,1); %Copy time vectors of the longer matrix to the interpolated matrix to eliminate NaNs

if (X_len>Y_len)
    X_new = overlap_X;
    Y_new = interped_matrix;
elseif(Y_len>X_len)
    X_new = interped_matrix;
    Y_new = overlap_Y;
end

return