function limit_check(checked_orb, checked_ef, checked_mag, tmp_directory, orbitname)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Megan Van Welie
% Worcester Polytechnic Institute
% Silicon Valley MQP 2011
% at SRI International
% megan6459@gmail.com
%
% This function finds the minimum and maximum values of all data used in the
% histogram plots. These limits are used in orbit_stats_plots where they
% are used to create the  boundries of the histograms. 
%
%
% Expected format of input matrices:
% checked_orb(:,1)       = unix time
% checked_orb(:,2:4)     = altitude, latitude, lnggitude (degrees)
%
% checked_ef(:,1)      = unix time
% checked_ef(:,2)      = electric field x (DCS2)
% checked_ef(:,3)      = electric field z (DCS2)
% checked_ef(:,4:6)    = altitude, latitude, longitude (degrees)
%
% checked_mag(:,1)        = unix time
% checked_mag(:,2:4)      = delta-b x,y,z (GEI)
% checked_mag(:,5:7)      = B x,y,z (GEI)  
% checked_mag(:,8:10)     = altitude, latitude, longitude (degrees)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Global variable to hold all maximum and minimum values
global min_max_vals

% Only take minimum and maximums if the input matrices are not empty
if(~isempty(checked_orb) && ~isempty(checked_ef) && ~isempty(checked_mag))
    save(strcat(tmp_directory,'orb\', orbitname, '_orb'), 'checked_orb');
    
%************ Check Orbit Altitude, Latitude, Longitude *******************
    if min(checked_orb(:,3)) < min_max_vals.orb_lat(1)
        min_max_vals.orb_lat(1) = min(checked_orb(:,3));
    end
    if min(checked_orb(:,4)) < min_max_vals.orb_lng(1)
        min_max_vals.orb_lng(1) = min(checked_orb(:,4));
    end
    if min(checked_orb(:,2)) < min_max_vals.orb_alt(1)
        min_max_vals.orb_alt(1) = min(checked_orb(:,2));
    end

    if max(checked_orb(:,3)) > min_max_vals.orb_lat(2)
        min_max_vals.orb_lat(2) = max(checked_orb(:,3));
    end
    if max(checked_orb(:,4)) > min_max_vals.orb_lng(2)
        min_max_vals.orb_lng(2) = max(checked_orb(:,4));
    end
    if max(checked_orb(:,2)) > min_max_vals.orb_alt(2)
        min_max_vals.orb_alt(2) = max(checked_orb(:,2));
    end
    clearvars checked_orb

    save(strcat(tmp_directory,'ef\', orbitname, '_ef'), 'checked_ef');
    
%************ Check Orbit Electric Field Along V (DCS2 X) *****************
    

    if min(checked_ef(:,2)) < min_max_vals.e_av_x(1)
        min_max_vals.e_av_x(1) = min(checked_ef(:,2));
    end

    if max(checked_ef(:,2)) > min_max_vals.e_av_x(2)
        min_max_vals.e_av_x(2) = max(checked_ef(:,2));
    end

    
%************ Check Orbit Electric Field Near B (DCS2 Z) ******************

    if min(checked_ef(:,3)) < min_max_vals.e_nb_x(1)
        min_max_vals.e_nb_x(1) = min(checked_ef(:,3));
    end
    
    if max(checked_ef(:,3)) > min_max_vals.e_nb_x(2)
        min_max_vals.e_nb_x(2) = max(checked_ef(:,3));
    end

%************ Check Electric Field Altitude, Latitude, Longitude **********
    if min(checked_ef(:,5)) < min_max_vals.e_lat(1)
        min_max_vals.e_lat(1) = min(checked_ef(:,5));
    end
    if min(checked_ef(:,6)) < min_max_vals.e_lng(1)
        min_max_vals.e_lng(1) = min(checked_ef(:,6));
    end
    if min(checked_ef(:,4)) < min_max_vals.e_alt(1)
        min_max_vals.e_alt(1) = min(checked_ef(:,4));
    end

    if max(checked_ef(:,5)) > min_max_vals.e_lat(2)
        min_max_vals.e_lat(2) = max(checked_ef(:,5));
    end
    if max(checked_ef(:,6)) > min_max_vals.e_lng(2)
        min_max_vals.e_lng(2) = max(checked_ef(:,6));
    end
    if max(checked_ef(:,4)) > min_max_vals.e_alt(2)
        min_max_vals.e_alt(2) = max(checked_ef(:,4));
    end
    clearvars checked_ef

    save(strcat(tmp_directory,'mag\', orbitname, '_mag'), 'checked_mag');

%**************** Check Delta-B X,Y,Z (DCS2)*******************************    
    if min(checked_mag(:,2)) < min_max_vals.db_x(1)
        min_max_vals.db_x(1) = min(checked_mag(:,2));
    end
    if min(checked_mag(:,3)) < min_max_vals.db_y(1)
        min_max_vals.db_y(1) = min(checked_mag(:,3));
    end
    if min(checked_mag(:,4)) < min_max_vals.db_z(1)
        min_max_vals.db_z(1) = min(checked_mag(:,4));
    end
    
    if max(checked_mag(:,2)) > min_max_vals.db_x(2)
        min_max_vals.db_x(2) = max(checked_mag(:,2));
    end
    if max(checked_mag(:,3)) > min_max_vals.db_y(2)
        min_max_vals.db_y(2) = max(checked_mag(:,3));
    end
    if max(checked_mag(:,4)) > min_max_vals.db_z(2)
        min_max_vals.db_z(2) = max(checked_mag(:,4));
    end


%**************** Check Total-B X,Y,Z (DCS2)*******************************       
    if min(checked_mag(:,5)) < min_max_vals.b_x(1)
        min_max_vals.b_x(1) = min(checked_mag(:,5));
    end
    if min(checked_mag(:,6)) < min_max_vals.b_y(1)
        min_max_vals.b_y(1) = min(checked_mag(:,6));
    end
    if min(checked_mag(:,7)) < min_max_vals.b_z(1)
        min_max_vals.b_z(1) = min(checked_mag(:,7));
    end
    
    if max(checked_mag(:,5)) > min_max_vals.b_x(2)
        min_max_vals.b_x(2) = max(checked_mag(:,5));
    end
    if max(checked_mag(:,6)) > min_max_vals.b_y(2)
        min_max_vals.b_y(2) = max(checked_mag(:,6));
    end
    if max(checked_mag(:,7)) > min_max_vals.b_z(2)
        min_max_vals.b_z(2) = max(checked_mag(:,7));
    end
    
    
%************ Check Magnetic Field Altitude, Latitude, Longitude **********    
    if min(checked_mag(:,9)) < min_max_vals.mag_lat(1)
        min_max_vals.mag_lat(1) = min(checked_mag(:,9));
    end
    if min(checked_mag(:,10)) < min_max_vals.mag_lng(1)
        min_max_vals.mag_lng(1) = min(checked_mag(:,10));
    end
    if min(checked_mag(:,8)) < min_max_vals.mag_alt(1)
        min_max_vals.mag_alt(1) = min(checked_mag(:,8));
    end
    
    if max(checked_mag(:,9)) > min_max_vals.mag_lat(2)
        min_max_vals.mag_lat(2) = max(checked_mag(:,9));
    end
    if max(checked_mag(:,10)) > min_max_vals.mag_lng(2)
        min_max_vals.mag_lng(2) = max(checked_mag(:,10));
    end
    if max(checked_mag(:,8)) > min_max_vals.mag_alt(2)
        min_max_vals.mag_alt(2) = max(checked_mag(:,8));
    end
    clearvars checked_mag
end

end