function [ limited_unix_time_matrix, orbitLow, orbitHigh ] = limit_kp( fastdata, orbitLow, orbitHigh, unix_time_matrix )
%LIMIT_KP 
%   
%   Author: Steven Chen
%           Feb. 17, 2011
%           googly.bear@gmail.com
%
%   INPUT:
%       Input containing the directory of fastdata, the starting orbit
%       range, the ending orbit range, and the original unix_time_matrix
%
%       fastdata - directory holding the FAST data
%       orbitLow - starting orbit range
%       orbitHigh - ending orbit range
%       unix_time_matrix - non-limited unix_time_matrix to the orbit range
%       values
%
%   OUPUT:
%       Ouputs a limited unix_time_matrix that is constrained to the orbit
%       range values. Also outputs the new orbitLow and orbitHigh
%
%
%   NOTE:
%       This is purely a helper function and should not be used by itself.
%

    dir_listing = dir(fastdata);    %   Gets a listing of the directories
    startdir = dir_listing(3).name; %   Gets the starting directory skipping '.' and '..'
    enddir = dir_listing(end).name; %   Gets the ending directory

    cprintf('blue','Found orbit directories from %s to %s.\n',startdir,enddir);
    %   This assumes that all folders are existing and are sequential

    %   Flags. Once the lower or higher bound is found set to 1.
    low_hit = 0;
    high_hit = 0;
    
    while 1
        %   Sets the pathing for all the files. Only accepts valid orbit files
        orbitname = dir_listing(2 + orbitLow).name; % Skips the initial 2 folders to start at the initial count
        orb_path_low = strcat(fastdata,  orbitname, '\', orbitname, '_orb.cdf');
        ef_path_low = strcat(fastdata, orbitname, '\', orbitname, '_ef.cdf');
        db_path_low = strcat(fastdata, orbitname, '\', orbitname, '_mag.cdf');
        sa_path_low = strcat(fastdata, orbitname, '\', orbitname, '_sa.cdf');
        iesorbitname_low = strcat('fa_k0_ies_0',int2str(orbitLow),'_v04.cdf');
        eesorbitname_low = strcat('fa_k0_ees_0',int2str(orbitLow),'_v04.cdf');
        ies_path_low = strcat(fastdata, orbitname, '\', iesorbitname_low);
        ees_path_low = strcat(fastdata, orbitname, '\', eesorbitname_low);

        %   Sets the pathing for all the files. Only accepts valid orbit files
        orbitname = dir_listing(2 + orbitHigh).name; % Skips the initial 2 folders to start at the initial count
        orb_path_high = strcat(fastdata, orbitname, '\', orbitname, '_orb.cdf');
        ef_path_high = strcat(fastdata, orbitname, '\', orbitname, '_ef.cdf');
        db_path_high = strcat(fastdata, orbitname, '\', orbitname, '_mag.cdf');
        sa_path_high = strcat(fastdata, orbitname, '\', orbitname, '_sa.cdf');
        iesorbitname_high = strcat('fa_k0_ies_0',int2str(orbitHigh),'_v04.cdf');
        eesorbitname_high = strcat('fa_k0_ees_0',int2str(orbitHigh),'_v04.cdf');
        ies_path_high = strcat(fastdata, orbitname, '\', iesorbitname_high);
        ees_path_high = strcat(fastdata, orbitname, '\', eesorbitname_high);

        if(exist(orb_path_low, 'file') == 2 ...
                && exist(ef_path_low, 'file') == 2 ...
                && exist(db_path_low, 'file') == 2 ...
                && exist(sa_path_low, 'file') == 2 ...
                && exist(ies_path_low, 'file') == 2 ...
                && exist(ees_path_low, 'file') == 2 ...
                && low_hit == 0)
            %   Goes until it hits an orbit from lowest orbit -> +1 of that
            %   orbit
            timerange = cdfread(ef_path_low, 'CombineRecords', true, 'Variable', 'TIME');
            unix_time_matrix(unix_time_matrix < (timerange(1)-10800)) = [];
            low_hit = 1;
        elseif(low_hit ~=1)
            orbitLow = orbitLow +1;     %   Going up inclusive -> <-
        end

        if(exist(orb_path_high, 'file') == 2 ...
                && exist(ef_path_high, 'file') == 2 ...
                && exist(db_path_high, 'file') == 2 ...
                && exist(sa_path_high, 'file') == 2 ...
                && exist(ies_path_high, 'file') == 2 ...
                && exist(ees_path_high, 'file') == 2 ...
                && high_hit == 0)
            %   Goes until it hits an orbit from highest orbit -> -1 of that
            %   orbit
            timerange = cdfread(ef_path_high, 'CombineRecords', true, 'Variable', 'TIME');
            unix_time_matrix(unix_time_matrix > timerange(end)) = [];
            high_hit = 1;
        elseif(high_hit ~= 1)
            orbitHigh = orbitHigh -1;   %   Going down inclusive -> <-
        end
        
        %   Removes the kp indices that are not within the orbit range
        if(orbitLow >= orbitHigh )
            unix_time_matrix(unix_time_matrix < timerange(1)) = [];
            unix_time_matrix(unix_time_matrix > timerange(end)) = [];
            break;
        end
        
        if(low_hit == 1 && high_hit == 1)
         break;
        end
        
    end

    limited_unix_time_matrix = unix_time_matrix;
end

